@@ -15,10 +15,11 @@ parse_desc_data = function(desc) {
   desc$default_target_attribute = make.names(desc$default_target_attribute)
   desc$upload_date = strptime(desc$upload_date, format = "%Y-%m-%dT%H:%M:%S", tz = "UTC")
   desc$processing_date = strptime(desc$processing_date, format = "%Y-%m-%d %H:%M:%S", tz = "UTC")
-  # remove_named(desc, c("file_id", "description", "md5_checksum"))
-
   # OpenML (sometimes) uploaded the ignore_attributes comma-seperated
   ignore_attribute = map(desc$ignore_attribute, function(x) strsplit(x, ",")[[1L]])
-  desc$ignore_attribute = unlist(ignore_attribute)
+  desc$ignore_attribute = make.unique(make.names(unlist(ignore_attribute)))
+  if (anyDuplicated(desc$ignore_attribute)) {
+    stopf("No unique names after conversion. This happened because ignore attribute names are not valid R names and had to be converted, which created duplicates.") # nolint
+  }
   return(desc)
 }
