@@ -88,7 +88,8 @@ as_duckdb_backend_character = function(data, primary_key = NULL, factors) {
     tbl = "mlr3db_view_recoded"
     type = table_info$type
     vars = paste0("\"", vars_orig, "\"")
-    vars[type == "BOOLEAN"] = paste0(vars[type == "BOOLEAN"], "::VARCHAR")
+    tmp = vars[type == "BOOLEAN"]
+    vars[type == "BOOLEAN"] = paste0(tmp, "::VARCHAR as", tmp)
     vars = paste(vars, collapse = ", ")
 
     query = sprintf("CREATE OR REPLACE VIEW '%s' AS SELECT %s from '%s'", tbl, vars, tbl_prev)
@@ -136,3 +137,30 @@ as_duckdb_backend_character = function(data, primary_key = NULL, factors) {
   backend
 }
 
+
+
+#' @title Delete an object from OpenML
+#' @description This function can be used to delete objects from the OpenML server.
+#'
+#' @param type (`character(1)`)
+#'  What type of object should be deleted ("flow", "run", "task", "data", "study" / "collection")
+#' @param id (`integer(1)`)
+#'  The id of the object that will be deleted.
+#' @param api_key (`character(1)`)
+#'  The API key to perform the action, if left NULL it first tries getOption("mlr3oml.api_key") and
+#'  then Sys.getenv("OMLAPIKEY").
+#' @param server (`character(1)`)
+#'  The server address, defaults to `get_server()`.
+#' @param confirm (`logical(1)`)
+#'  Whether the deletion has to be confirmed interactively.
+#' @noRd
+delete = function(type, id, api_key = NULL, test_server = NULL) {
+  server = get_server(assert_flag(test_server))
+  if (is.null(api_key)) api_key = get_api_key(server)
+  assert_choice(type, choices = c("flow", "run", "task", "data", "study", "collection"))
+
+  if (type == "collection") type = "study"
+  url = sprintf("%s/%s/%s", server, type, id)
+  response = httr::DELETE(url, query = list(api_key = api_key))
+  response
+}
